@@ -36,6 +36,12 @@ class WialonUnit(WialonBase):
         )
         return response.get("item", {}).get("id")
 
+    @property
+    def available_commands(self) -> dict:
+        return self.session.wialon_api.core_get_hw_cmds(
+            **{"deviceTypeId": 0, "unitId": self.id}
+        )
+
     def execute_command(
         self,
         name: str,
@@ -133,15 +139,6 @@ class WialonUnit(WialonBase):
             **{"itemId": self.id, "phoneNumber": quote_plus(phone)}
         )
 
-    def clean_phone_numbers(self, phones: list[str]) -> list[str]:
-        cleaned_phones = []
-        for num in phones:
-            if "," in num:
-                cleaned_phones.extend(num.split(","))
-            else:
-                cleaned_phones.append(num)
-        return cleaned_phones
-
     def get_phone_numbers(self) -> list[str]:
         """
         Retrieves all phone numbers assigned to the unit.
@@ -167,6 +164,15 @@ class WialonUnit(WialonBase):
             phone_numbers.extend(phones_2)
         return list(dict.fromkeys(phone_numbers))  # Removes duplicate phone numbers
 
+    def clean_phone_numbers(self, phones: list[str]) -> list[str]:
+        cleaned_phones = []
+        for num in phones:
+            if "," in num:
+                cleaned_phones.extend(num.split(","))
+            else:
+                cleaned_phones.append(num)
+        return cleaned_phones
+
     def _get_afield_phone_numbers(self, key: str = "to_number") -> list[str] | None:
         """
         Retrives any phone numbers saved in an admin field by key.
